@@ -1,5 +1,4 @@
 pub mod action;
-mod actions;
 pub mod application;
 mod key;
 pub mod key_action;
@@ -7,6 +6,9 @@ pub mod key_press;
 mod keymap;
 mod modmap;
 
+#[cfg(test)]
+mod tests;
+
 extern crate serde_yaml;
 
 use keymap::Keymap;
